@@ -2,10 +2,12 @@ context('annotationDiagnosticMultiplot()')
 
 ## Test the generation of multiplot for each compound
 
-skip_if(getRversion() >= "3.6")
 skip_if_not_installed('faahKO',  minimum_version = '1.18.0')
 library(faahKO)
 
+# remove Rplots.pdf created by ggplot2
+on.exit( tryCatch({ file.remove('./Rplots.pdf') }, error=function(e){ invisible() }, warning=function(w){ invisible() }) )
+
 
 ## Input data
 # spectraPaths
@@ -14,13 +16,13 @@ input_spectraPaths  <- c(system.file('cdf/KO/ko15.CDF', package = "faahKO"),
                          system.file('cdf/KO/ko18.CDF', package = "faahKO"))
 
 # targetFeatTable
-input_targetFeatTable     <- data.frame(matrix(vector(), 2, 8, dimnames=list(c(), c("cpdID", "cpdName", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax"))), stringsAsFactors=F)
+input_targetFeatTable     <- data.frame(matrix(vector(), 2, 8, dimnames=list(c(), c("cpdID", "cpdName", "rtMin", "rt", "rtMax", "mzMin", "mz", "mzMax"))), stringsAsFactors=FALSE)
 input_targetFeatTable[1,] <- c("ID-1", "Cpd 1", 3310., 3344.888, 3390., 522.194778, 522.2, 522.205222)
 input_targetFeatTable[2,] <- c("ID-2", "Cpd 2", 3280., 3385.577, 3440., 496.195038, 496.2, 496.204962)
 input_targetFeatTable[,c(3:8)] <- sapply(input_targetFeatTable[,c(3:8)], as.numeric)
 
 # acquisitionTime
-input_acquisitionTime <- c(Sys.time(), Sys.time()+900, Sys.time()+1800)
+input_acquisitionTime <- as.POSIXct(c(Sys.time(), Sys.time()+900, Sys.time()+1800))
 
 # peakFit
 # 1
@@ -42,54 +44,54 @@ input_peakFit   <- list(list(cFit1.1, cFit1.2), list(cFit2.1, cFit2.2), list(cFi
 
 # dataPoint
 tmp_raw_data1  	  <- MSnbase::readMSData(input_spectraPaths[1], centroided=TRUE, mode='onDisk')
-ROIDataPoints1    <- extractSignalRawData(tmp_raw_data1, rt=input_targetFeatTable[,c('rtMin','rtMax')], mz=input_targetFeatTable[,c('mzMin','mzMax')], verbose=F)
+ROIDataPoints1    <- extractSignalRawData(tmp_raw_data1, rt=input_targetFeatTable[,c('rtMin','rtMax')], mz=input_targetFeatTable[,c('mzMin','mzMax')], verbose=FALSE)
 tmp_raw_data2  	  <- MSnbase::readMSData(input_spectraPaths[2], centroided=TRUE, mode='onDisk')
-ROIDataPoints2    <- extractSignalRawData(tmp_raw_data2, rt=input_targetFeatTable[,c('rtMin','rtMax')], mz=input_targetFeatTable[,c('mzMin','mzMax')], verbose=F)
+ROIDataPoints2    <- extractSignalRawData(tmp_raw_data2, rt=input_targetFeatTable[,c('rtMin','rtMax')], mz=input_targetFeatTable[,c('mzMin','mzMax')], verbose=FALSE)
 tmp_raw_data3  	  <- MSnbase::readMSData(input_spectraPaths[3], centroided=TRUE, mode='onDisk')
-ROIDataPoints3    <- extractSignalRawData(tmp_raw_data3, rt=input_targetFeatTable[,c('rtMin','rtMax')], mz=input_targetFeatTable[,c('mzMin','mzMax')], verbose=F)
+ROIDataPoints3    <- extractSignalRawData(tmp_raw_data3, rt=input_targetFeatTable[,c('rtMin','rtMax')], mz=input_targetFeatTable[,c('mzMin','mzMax')], verbose=FALSE)
 input_dataPoints  <- list(ROIDataPoints1, ROIDataPoints2, ROIDataPoints3)
 
 # input annotationDiagnosticPlotList
 # compound 1
-expected_EICFit1                  <- plotEICFit(ROIDataPointSampleList = list(ROIDataPoints1[[1]], ROIDataPoints2[[1]], ROIDataPoints3[[1]]),
-                                                curveFitSampleList = list(cFit1.1, cFit1.2, cFit1.2),
-                                                rtMin = c(3309.7589296586070, 3326.1063495851854, 3333.8625894557053),
-                                                rtMax = c(3385.4098874628098, 3407.2726475892355, 3407.4362838927614),
-                                                sampling = 250,
-                                                sampleColour = NULL,
-                                                verbose = FALSE)
-expected_rtPeakwidthVert1         <- plotPeakwidth(apexValue = c(3346.8277590361445, 3365.102, 3368.233),
-                                                   widthMin = c(3309.7589296586070, 3326.1063495851854, 3333.8625894557053),
-                                                   widthMax = c(3385.4098874628098, 3407.2726475892355, 3407.4362838927614),
-                                                   acquTime = input_acquisitionTime,
-                                                   sampleColour = NULL,
-                                                   varName = 'Retention Time (sec)',
-                                                   rotateAxis = TRUE,
-                                                   verbose = FALSE)
-expected_rtPeakwidthHorzRunOrder1 <- plotPeakwidth(apexValue = c(3346.8277590361445, 3365.102, 3368.233),
-                                                   widthMin = c(3309.7589296586070, 3326.1063495851854, 3333.8625894557053),
-                                                   widthMax = c(3385.4098874628098, 3407.2726475892355, 3407.4362838927614),
-                                                   acquTime = input_acquisitionTime,
-                                                   sampleColour = NULL,
-                                                   varName = 'Retention Time (sec)',
-                                                   rotateAxis = FALSE,
-                                                   verbose = FALSE)
-expected_mzPeakwidthHorzRunOrder1 <- plotPeakwidth(apexValue = c(522.20001220703125, 522.20001220703125, 522.20001220703125),
-                                                   widthMin = c(522.194778, 522.194778, 522.194778),
-                                                   widthMax = c(522.205222, 522.205222, 522.205222),
-                                                   acquTime = input_acquisitionTime,
-                                                   sampleColour = NULL,
-                                                   varName = 'm/z',
-                                                   rotateAxis = FALSE,
-                                                   verbose = FALSE)
-expected_areaRunOrder1            <- plotPeakwidth(apexValue = c(26133726.681124408, 24545301.622835573, 21447174.404490683),
-                                                   widthMin = NULL,
-                                                   widthMax = NULL,
-                                                   acquTime = input_acquisitionTime,
-                                                   sampleColour = NULL,
-                                                   varName = 'Peak Area',
-                                                   rotateAxis = FALSE,
-                                                   verbose = FALSE)
+expected_EICFit1                  <- peakPantheR_plotEICFit(ROIDataPointSampleList = list(ROIDataPoints1[[1]], ROIDataPoints2[[1]], ROIDataPoints3[[1]]),
+                                                            curveFitSampleList = list(cFit1.1, cFit1.2, cFit1.2),
+                                                            rtMin = c(3309.7589296586070, 3326.1063495851854, 3333.8625894557053),
+                                                            rtMax = c(3385.4098874628098, 3407.2726475892355, 3407.4362838927614),
+                                                            sampling = 250,
+                                                            sampleColour = NULL,
+                                                            verbose = FALSE)
+expected_rtPeakwidthVert1         <- peakPantheR_plotPeakwidth(apexValue = c(3346.8277590361445, 3365.102, 3368.233),
+                                                               widthMin = c(3309.7589296586070, 3326.1063495851854, 3333.8625894557053),
+                                                               widthMax = c(3385.4098874628098, 3407.2726475892355, 3407.4362838927614),
+                                                               acquTime = input_acquisitionTime,
+                                                               sampleColour = NULL,
+                                                               varName = 'Retention Time (sec)',
+                                                               rotateAxis = TRUE,
+                                                               verbose = FALSE)
+expected_rtPeakwidthHorzRunOrder1 <- peakPantheR_plotPeakwidth(apexValue = c(3346.8277590361445, 3365.102, 3368.233),
+                                                               widthMin = c(3309.7589296586070, 3326.1063495851854, 3333.8625894557053),
+                                                               widthMax = c(3385.4098874628098, 3407.2726475892355, 3407.4362838927614),
+                                                               acquTime = input_acquisitionTime,
+                                                               sampleColour = NULL,
+                                                               varName = 'Retention Time (sec)',
+                                                               rotateAxis = FALSE,
+                                                               verbose = FALSE)
+expected_mzPeakwidthHorzRunOrder1 <- peakPantheR_plotPeakwidth(apexValue = c(522.20001220703125, 522.20001220703125, 522.20001220703125),
+                                                               widthMin = c(522.194778, 522.194778, 522.194778),
+                                                               widthMax = c(522.205222, 522.205222, 522.205222),
+                                                               acquTime = input_acquisitionTime,
+                                                               sampleColour = NULL,
+                                                               varName = 'm/z',
+                                                               rotateAxis = FALSE,
+                                                               verbose = FALSE)
+expected_areaRunOrder1            <- peakPantheR_plotPeakwidth(apexValue = c(26133726.681124408, 24545301.622835573, 21447174.404490683),
+                                                               widthMin = NULL,
+                                                               widthMax = NULL,
+                                                               acquTime = input_acquisitionTime,
+                                                               sampleColour = NULL,
+                                                               varName = 'Peak Area',
+                                                               rotateAxis = FALSE,
+                                                               verbose = FALSE)
 expected_rtHistogram1             <- plotHistogram(var = c(3346.8277590361445, 3365.102, 3368.233), 
                                                    varName='Retention Time (sec)',
                                                    density=TRUE)
@@ -100,45 +102,45 @@ expected_areaHistogram1           <- plotHistogram(var = c(26133726.681124408, 2
                                                    varName='Peak Area', 
                                                    density=TRUE)
 # compound 2
-expected_EICFit2                  <- plotEICFit(ROIDataPointSampleList = list(ROIDataPoints1[[2]], ROIDataPoints2[[2]], ROIDataPoints3[[2]]),
-                                                curveFitSampleList = list(cFit1.2, cFit2.2, cFit3.2),
-                                                rtMin = c(3345.3766648628907, 3365.0238566258713, 3373.3998828113113),
-                                                rtMax = c(3428.2788374983961, 3453.4049569205681, 3454.4490330927388),
-                                                sampling = 250,
-                                                sampleColour = NULL,
-                                                verbose = FALSE)
-expected_rtPeakwidthVert2         <- plotPeakwidth(apexValue = c(3386.5288072289159, 3405.791, 3413.4952530120481),
-                                                   widthMin = c(3345.3766648628907, 3365.0238566258713, 3373.3998828113113),
-                                                   widthMax = c(3428.2788374983961, 3453.4049569205681, 3454.4490330927388),
-                                                   acquTime = NULL,
-                                                   sampleColour = NULL,
-                                                   varName = 'Retention Time (sec)',
-                                                   rotateAxis = TRUE,
-                                                   verbose = FALSE)
-expected_rtPeakwidthHorzRunOrder2 <- plotPeakwidth(apexValue = c(3386.5288072289159, 3405.791, 3413.4952530120481),
-                                                   widthMin = c(3345.3766648628907, 3365.0238566258713, 3373.3998828113113),
-                                                   widthMax = c(3428.2788374983961, 3453.4049569205681, 3454.4490330927388),
-                                                   acquTime = input_acquisitionTime,
-                                                   sampleColour = NULL,
-                                                   varName = 'Retention Time (sec)',
-                                                   rotateAxis = FALSE,
-                                                   verbose = FALSE)
-expected_mzPeakwidthHorzRunOrder2 <- plotPeakwidth(apexValue = c(496.20001220703125, 496.20001220703125, 496.20001220703125),
-                                                   widthMin = c(496.20001220703125, 496.195038, 496.195038),
-                                                   widthMax = c(496.20001220703125, 496.204962, 496.204962),
-                                                   acquTime = input_acquisitionTime,
-                                                   sampleColour = NULL,
-                                                   varName = 'm/z',
-                                                   rotateAxis = FALSE,
-                                                   verbose = FALSE)
-expected_areaRunOrder2            <- plotPeakwidth(apexValue = c(35472141.333024293, 37207579.286265120, 35659353.614476241),
-                                                   widthMin = NULL,
-                                                   widthMax = NULL,
-                                                   acquTime = input_acquisitionTime,
-                                                   sampleColour = NULL,
-                                                   varName = 'Peak Area',
-                                                   rotateAxis = FALSE,
-                                                   verbose = FALSE)
+expected_EICFit2                  <- peakPantheR_plotEICFit(ROIDataPointSampleList = list(ROIDataPoints1[[2]], ROIDataPoints2[[2]], ROIDataPoints3[[2]]),
+                                                            curveFitSampleList = list(cFit1.2, cFit2.2, cFit3.2),
+                                                            rtMin = c(3345.3766648628907, 3365.0238566258713, 3373.3998828113113),
+                                                            rtMax = c(3428.2788374983961, 3453.4049569205681, 3454.4490330927388),
+                                                            sampling = 250,
+                                                            sampleColour = NULL,
+                                                            verbose = FALSE)
+expected_rtPeakwidthVert2         <- peakPantheR_plotPeakwidth(apexValue = c(3386.5288072289159, 3405.791, 3413.4952530120481),
+                                                               widthMin = c(3345.3766648628907, 3365.0238566258713, 3373.3998828113113),
+                                                               widthMax = c(3428.2788374983961, 3453.4049569205681, 3454.4490330927388),
+                                                               acquTime = NULL,
+                                                               sampleColour = NULL,
+                                                               varName = 'Retention Time (sec)',
+                                                               rotateAxis = TRUE,
+                                                               verbose = FALSE)
+expected_rtPeakwidthHorzRunOrder2 <- peakPantheR_plotPeakwidth(apexValue = c(3386.5288072289159, 3405.791, 3413.4952530120481),
+                                                               widthMin = c(3345.3766648628907, 3365.0238566258713, 3373.3998828113113),
+                                                               widthMax = c(3428.2788374983961, 3453.4049569205681, 3454.4490330927388),
+                                                               acquTime = input_acquisitionTime,
+                                                               sampleColour = NULL,
+                                                               varName = 'Retention Time (sec)',
+                                                               rotateAxis = FALSE,
+                                                               verbose = FALSE)
+expected_mzPeakwidthHorzRunOrder2 <- peakPantheR_plotPeakwidth(apexValue = c(496.20001220703125, 496.20001220703125, 496.20001220703125),
+                                                               widthMin = c(496.20001220703125, 496.195038, 496.195038),
+                                                               widthMax = c(496.20001220703125, 496.204962, 496.204962),
+                                                               acquTime = input_acquisitionTime,
+                                                               sampleColour = NULL,
+                                                               varName = 'm/z',
+                                                               rotateAxis = FALSE,
+                                                               verbose = FALSE)
+expected_areaRunOrder2            <- peakPantheR_plotPeakwidth(apexValue = c(35472141.333024293, 37207579.286265120, 35659353.614476241),
+                                                               widthMin = NULL,
+                                                               widthMax = NULL,
+                                                               acquTime = input_acquisitionTime,
+                                                               sampleColour = NULL,
+                                                               varName = 'Peak Area',
+                                                               rotateAxis = FALSE,
+                                                               verbose = FALSE)
 expected_rtHistogram2             <- plotHistogram(var = c(3386.5288072289159, 3405.791, 3413.4952530120481), 
                                                    varName='Retention Time (sec)',
                                                    density=TRUE)
@@ -265,11 +267,11 @@ test_that('raise warnings/error', {
   expect_equal(length(result_warn8$result[[2]]), 9)
   
   # missing title for cpd 1
-  input_missareaHistogram      <- input_annotationDiagnosticPlotList
-  input_missareaHistogram[[1]] <- input_missareaHistogram[[1]][c("EICFit", "rtPeakwidthVert", "rtPeakwidthHorzRunOrder", "mzPeakwidthHorzRunOrder", "areaRunOrder", "rtHistogram", "mzHistogram", "areaHistogram")]
-  result_warn8                <- evaluate_promise(annotationDiagnosticMultiplot(input_missareaHistogram))
-  expect_equal(result_warn8$message[[1]], expected_message)
-  expect_equal(result_warn8$result[[1]], NULL)
-  expect_equal(sort(class(result_warn8$result[[2]])), gtable_class)
-  expect_equal(length(result_warn8$result[[2]]), 9)
+  input_misstitleHistogram      <- input_annotationDiagnosticPlotList
+  input_misstitleHistogram[[1]] <- input_misstitleHistogram[[1]][c("EICFit", "rtPeakwidthVert", "rtPeakwidthHorzRunOrder", "mzPeakwidthHorzRunOrder", "areaRunOrder", "rtHistogram", "mzHistogram", "areaHistogram")]
+  result_warn9                <- evaluate_promise(annotationDiagnosticMultiplot(input_misstitleHistogram))
+  expect_equal(result_warn9$message[[1]], expected_message)
+  expect_equal(result_warn9$result[[1]], NULL)
+  expect_equal(sort(class(result_warn9$result[[2]])), gtable_class)
+  expect_equal(length(result_warn9$result[[2]]), 9)
 })
